@@ -1,4 +1,4 @@
-#include "perly-5.21.4.h"
+#include "perly-5.19.4.h"
 enum token_type {
     TOKENTYPE_NONE,
     TOKENTYPE_IVAL,
@@ -59,10 +59,10 @@ static struct debug_tokens {
     { OROP,		TOKENTYPE_IVAL,		"OROP" },
     { OROR,		TOKENTYPE_NONE,		"OROR" },
     { PACKAGE,		TOKENTYPE_NONE,		"PACKAGE" },
+    { PEG,		TOKENTYPE_NONE,		"PEG" },
     { PLUGEXPR,		TOKENTYPE_OPVAL,	"PLUGEXPR" },
     { PLUGSTMT,		TOKENTYPE_OPVAL,	"PLUGSTMT" },
     { PMFUNC,		TOKENTYPE_OPVAL,	"PMFUNC" },
-    { POSTJOIN,		TOKENTYPE_NONE,		"POSTJOIN" },
     { POSTDEC,		TOKENTYPE_NONE,		"POSTDEC" },
     { POSTINC,		TOKENTYPE_NONE,		"POSTINC" },
     { POWOP,		TOKENTYPE_OPNUM,	"POWOP" },
@@ -86,6 +86,14 @@ static struct debug_tokens {
     { WHILE,		TOKENTYPE_IVAL,		"WHILE" },
     { WORD,		TOKENTYPE_OPVAL,	"WORD" },
     { YADAYADA,		TOKENTYPE_IVAL,		"YADAYADA" },
+    /* added by Perl::Lexer */
+    { GRAMPROG, TOKENTYPE_OPNUM, "GRAMPROG" },
+    { GRAMEXPR, TOKENTYPE_OPNUM, "GRAMEXPR" },
+    { GRAMBLOCK, TOKENTYPE_OPNUM, "GRAMBLOCK" },
+    { GRAMBARESTMT, TOKENTYPE_OPNUM, "GRAMBARESTMT" },
+    { GRAMFULLSTMT, TOKENTYPE_OPNUM, "GRAMFULLSTMT" },
+    { GRAMSTMTSEQ, TOKENTYPE_OPNUM, "GRAMSTMTSEQ" },
+    { PREC_LOW, TOKENTYPE_OPNUM, "PREC_LOW" },
     { 0,		TOKENTYPE_NONE,		NULL }
 };
 
